@@ -1,7 +1,7 @@
-from marshmallow import fields, Schema
+from marshmallow import Schema, fields
 
-from microcosm_pubsub.conventions import created
 from microcosm_pubsub.codecs import PubSubMessageSchema
+from microcosm_pubsub.conventions import created
 from microcosm_pubsub.decorators import schema
 
 
@@ -15,6 +15,7 @@ class BatchedMessageSchema(Schema):
     message = fields.Raw(required=True)
     topic_arn = fields.String(required=True)
     opaque_data = fields.Raw(required=True)
+    message_attributes = fields.Raw(required=True)
 
 
 @schema
@@ -26,6 +27,3 @@ class MessageBatchSchema(PubSubMessageSchema):
     MEDIA_TYPE = created("batch_message")
 
     messages = fields.List(fields.Nested(BatchedMessageSchema), required=True)
-
-    def deserialize_media_type(self, obj):
-        return MessageBatchSchema.MEDIA_TYPE
